==> haskell-case-insensitive-1.2.0.6-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-case-insensitive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.6
id: case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
key: casei_4HKCZYPfrJALfK51ySNnwP
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/case-insensitive-1.2.0.6
hs-libraries: HScase-insensitive-1.2.0.6-4HKCZYPfrJALfK51ySNnwP
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.0.6-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-case-insensitive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.6
id: case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
key: casei_KREfefAtA7j6zRZtlU9vZn
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/case-insensitive-1.2.0.6
hs-libraries: HScase-insensitive-1.2.0.6-KREfefAtA7j6zRZtlU9vZn
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
